Index: sasmodels/models/barbell.c
===================================================================
--- sasmodels/models/barbell.c	(revision 1e7b0db0b7b4315c62b59e1d659332bcbc962b8f)
+++ sasmodels/models/barbell.c	(revision 592343f7d47ec3aad7ffa1ca242acb1346553ede)
@@ -33,5 +33,5 @@
         const double t = Gauss76Z[i]*zm + zb;
         const double radical = 1.0 - t*t;
-        const double bj = sas_J1c(qrst*sqrt(radical));
+        const double bj = sas_2J1x_x(qrst*sqrt(radical));
         const double Fq = cos(m*t + b) * radical * bj;
         total += Gauss76Wt[i] * Fq;
@@ -49,5 +49,5 @@
 {
     const double bell_fq = _bell_kernel(q, h, radius_bell, half_length, sin_alpha, cos_alpha);
-    const double bj = sas_J1c(q*radius*sin_alpha);
+    const double bj = sas_2J1x_x(q*radius*sin_alpha);
     const double si = sas_sinx_x(q*half_length*cos_alpha);
     const double cyl_fq = 2.0*M_PI*radius*radius*half_length*bj*si;
Index: sasmodels/models/capped_cylinder.c
===================================================================
--- sasmodels/models/capped_cylinder.c	(revision 1e7b0db0b7b4315c62b59e1d659332bcbc962b8f)
+++ sasmodels/models/capped_cylinder.c	(revision 592343f7d47ec3aad7ffa1ca242acb1346553ede)
@@ -39,5 +39,5 @@
         const double t = Gauss76Z[i]*zm + zb;
         const double radical = 1.0 - t*t;
-        const double bj = sas_J1c(qrst*sqrt(radical));
+        const double bj = sas_2J1x_x(qrst*sqrt(radical));
         const double Fq = cos(m*t + b) * radical * bj;
         total += Gauss76Wt[i] * Fq;
@@ -54,5 +54,5 @@
 {
     const double cap_Fq = _cap_kernel(q, h, radius_cap, half_length, sin_alpha, cos_alpha);
-    const double bj = sas_J1c(q*radius*sin_alpha);
+    const double bj = sas_2J1x_x(q*radius*sin_alpha);
     const double si = sas_sinx_x(q*half_length*cos_alpha);
     const double cyl_Fq = 2.0*M_PI*radius*radius*half_length*bj*si;
Index: sasmodels/models/core_shell_bicelle.c
===================================================================
--- sasmodels/models/core_shell_bicelle.c	(revision 1e7b0db0b7b4315c62b59e1d659332bcbc962b8f)
+++ sasmodels/models/core_shell_bicelle.c	(revision 592343f7d47ec3aad7ffa1ca242acb1346553ede)
@@ -55,6 +55,6 @@
     double sinarg2 = qq*(length+facthick)*cos_alpha;
 
-    be1 = sas_J1c(besarg1);
-    be2 = sas_J1c(besarg2);
+    be1 = sas_2J1x_x(besarg1);
+    be2 = sas_2J1x_x(besarg2);
     si1 = sas_sinx_x(sinarg1);
     si2 = sas_sinx_x(sinarg2);
Index: sasmodels/models/core_shell_bicelle_elliptical.c
===================================================================
--- sasmodels/models/core_shell_bicelle_elliptical.c	(revision 1e7b0db0b7b4315c62b59e1d659332bcbc962b8f)
+++ sasmodels/models/core_shell_bicelle_elliptical.c	(revision 592343f7d47ec3aad7ffa1ca242acb1346553ede)
@@ -85,6 +85,6 @@
             double besarg1 = qq*rr*sin_alpha;
             double besarg2 = qq*(rr+radthick)*sin_alpha;
-            be1 = sas_J1c(besarg1);
-            be2 = sas_J1c(besarg2);
+            be1 = sas_2J1x_x(besarg1);
+            be2 = sas_2J1x_x(besarg2);
             inner_sum += Gauss76Wt[j] *square(dr1*si1*be1 +
                                               dr2*si2*be2 +
@@ -129,6 +129,6 @@
     // ASSUME the sin_alpha is included in the separate integration over orientation of rod angle
     const double r = rad*sqrt(square(x_core*cos_nu) + cos_mu*cos_mu);
-    const double be1 = sas_J1c(qq*r);
-    const double be2 = sas_J1c( qq*(r + radthick ) );
+    const double be1 = sas_2J1x_x( qq*r );
+    const double be2 = sas_2J1x_x( qq*(r + radthick ) );
     const double si1 = sas_sinx_x( qq*halfheight*cos_val );
     const double si2 = sas_sinx_x( qq*(halfheight + facthick)*cos_val );
Index: sasmodels/models/core_shell_cylinder.c
===================================================================
--- sasmodels/models/core_shell_cylinder.c	(revision 1e7b0db0b7b4315c62b59e1d659332bcbc962b8f)
+++ sasmodels/models/core_shell_cylinder.c	(revision 592343f7d47ec3aad7ffa1ca242acb1346553ede)
@@ -11,5 +11,5 @@
 double _cyl(double vd, double besarg, double siarg)
 {
-    return vd * sas_sinx_x(siarg) * sas_J1c(besarg);
+    return vd * sas_sinx_x(siarg) * sas_2J1x_x(besarg);
 }
 
Index: sasmodels/models/cylinder.c
===================================================================
--- sasmodels/models/cylinder.c	(revision 1e7b0db0b7b4315c62b59e1d659332bcbc962b8f)
+++ sasmodels/models/cylinder.c	(revision 592343f7d47ec3aad7ffa1ca242acb1346553ede)
@@ -18,5 +18,5 @@
     const double qr = q*radius;
     const double qh = q*0.5*length; 
-    return sas_J1c(qr*sn) * sas_sinx_x(qh*cn);
+    return sas_2J1x_x(qr*sn) * sas_sinx_x(qh*cn);
 }
 
Index: sasmodels/models/elliptical_cylinder.c
===================================================================
--- sasmodels/models/elliptical_cylinder.c	(revision 1e7b0db0b7b4315c62b59e1d659332bcbc962b8f)
+++ sasmodels/models/elliptical_cylinder.c	(revision 592343f7d47ec3aad7ffa1ca242acb1346553ede)
@@ -39,5 +39,5 @@
             const double theta = ( Gauss20Z[j]*(vbj-vaj) + vaj + vbj )/2.0;
             const double r = sin_val*sqrt(rA - rB*cos(theta));
-            const double be = sas_J1c(q*r);
+            const double be = sas_2J1x_x(q*r);
             inner_sum += Gauss20Wt[j] * be * be;
         }
@@ -73,5 +73,5 @@
     // Given:    radius_major = r_ratio * radius_minor
     const double r = radius_minor*sqrt(square(r_ratio*cos_nu) + cos_mu*cos_mu);
-    const double be = sas_J1c(q*r);
+    const double be = sas_2J1x_x(q*r);
     const double si = sas_sinx_x(q*0.5*length*cos_val);
     const double Aq = be * si;
Index: sasmodels/models/flexible_cylinder.c
===================================================================
--- sasmodels/models/flexible_cylinder.c	(revision e6408d049d3598925e345d8adec1cdb0bb0c6adb)
+++ sasmodels/models/flexible_cylinder.c	(revision 592343f7d47ec3aad7ffa1ca242acb1346553ede)
@@ -14,5 +14,5 @@
 {
     const double contrast = sld - solvent_sld;
-    const double cross_section = sas_J1c(q*radius);
+    const double cross_section = sas_2J1x_x(q*radius);
     const double volume = M_PI*radius*radius*length;
     const double flex = Sk_WR(q, length, kuhn_length);
Index: sasmodels/models/flexible_cylinder_elliptical.c
===================================================================
--- sasmodels/models/flexible_cylinder_elliptical.c	(revision 92ce163837b3c51ecc732713d4a5ea719c037b29)
+++ sasmodels/models/flexible_cylinder_elliptical.c	(revision 592343f7d47ec3aad7ffa1ca242acb1346553ede)
@@ -22,5 +22,5 @@
         SINCOS(zi, sn, cn);
         const double arg = q*sqrt(a*a*sn*sn + b*b*cn*cn);
-        const double yyy = sas_J1c(arg);
+        const double yyy = sas_2J1x_x(arg);
         sum += Gauss76Wt[i] * yyy * yyy;
     }
Index: sasmodels/models/stacked_disks.c
===================================================================
--- sasmodels/models/stacked_disks.c	(revision 1e7b0db0b7b4315c62b59e1d659332bcbc962b8f)
+++ sasmodels/models/stacked_disks.c	(revision 592343f7d47ec3aad7ffa1ca242acb1346553ede)
@@ -53,5 +53,5 @@
     const double sinarg2 = q*(halfheight+thick_layer)*cos_alpha;
 
-    const double be1 = sas_J1c(besarg1);
+    const double be1 = sas_2J1x_x(besarg1);
     //const double be2 = sas_J1c(besarg2);
     const double be2 = be1;

Index: sasmodels/models/hollow_cylinder.c
===================================================================
--- sasmodels/models/hollow_cylinder.c	(revision 1e7b0db0b7b4315c62b59e1d659332bcbc962b8f)
+++ sasmodels/models/hollow_cylinder.c	(revision 592343f7d47ec3aad7ffa1ca242acb1346553ede)
@@ -20,9 +20,9 @@
 {
     const double qs = q*sin_val;
-    const double lam1 = sas_J1c((radius+thickness)*qs);
-    const double lam2 = sas_J1c(radius*qs);
+    const double lam1 = sas_2J1x_x((radius+thickness)*qs);
+    const double lam2 = sas_2J1x_x(radius*qs);
     const double gamma_sq = square(radius/(radius+thickness));
     //Note: lim_{thickness -> 0} psi = J0(radius*qs)
     //Note: lim_{radius -> 0} psi = sas_J1c(thickness*qs)
     const double psi = (lam1 - gamma_sq*lam2)/(1.0 - gamma_sq);	//SRK 10/19/00
     const double t2 = sas_sinx_x(0.5*q*length*cos_val);
@@ -20,9 +20,9 @@
     const double gamma_sq = square(radius/(radius+thickness));
-    //Note: lim_{thickness -> 0} psi = J0(radius*qs)
-    //Note: lim_{radius -> 0} psi = sas_J1c(thickness*qs)
+    //Note: lim_{thickness -> 0} psi = sas_J0(radius*qs)
+    //Note: lim_{radius -> 0} psi = sas_2J1x_x(thickness*qs)
     const double psi = (lam1 - gamma_sq*lam2)/(1.0 - gamma_sq);	//SRK 10/19/00
     const double t2 = sas_sinx_x(0.5*q*length*cos_val);